"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.payoutQueueResultParser = exports.payoutQueueItemAttemptIdParser = exports.payoutQueueQueryParser = exports.payoutStatusResultParser = exports.payoutResultParser = exports.payoutRetryBodyParser = exports.payoutBodyParser = exports.payoutBatchItemsParser = exports.withDryParser = exports.payoutParamsParser = exports.payoutAmountParser = void 0;
const zod_1 = __importDefault(require("zod"));
const parsers_1 = require("../currencies/parsers");
const constants_1 = require("./constants");
const parsers_serialized_1 = require("./parsers.serialized");
const parsers_common_1 = require("./parsers.common");
const queryParams_1 = require("../common/parsers/queryParams");
const parsers_2 = require("../parsers");
exports.payoutAmountParser = parsers_1.currencyAmountParser;
exports.payoutParamsParser = zod_1.default.object({
    [constants_1.PAYOUT_BATCH_ID_PARAM_NAME]: parsers_common_1.payoutBatchKeyParser,
});
exports.withDryParser = zod_1.default.object({
    dry: zod_1.default.boolean().optional().default(true),
});
exports.payoutBatchItemsParser = zod_1.default.record(parsers_serialized_1.payoutBatchItemCompositeKeySerializedParser, exports.payoutAmountParser);
exports.payoutBodyParser = zod_1.default
    .object({
    items: exports.payoutBatchItemsParser,
})
    .merge(exports.withDryParser);
exports.payoutRetryBodyParser = zod_1.default.object({}).merge(exports.withDryParser);
exports.payoutResultParser = zod_1.default.object({
    successes: zod_1.default.array(parsers_serialized_1.payoutBatchItemCompositeKeySerializedParser),
    failures: zod_1.default.record(parsers_serialized_1.payoutBatchItemCompositeKeySerializedParser, zod_1.default.string()),
});
const payoutQueueItemStatusParser = zod_1.default.object({
    all: exports.payoutBatchItemsParser,
    left: exports.payoutBatchItemsParser,
});
exports.payoutStatusResultParser = payoutQueueItemStatusParser;
exports.payoutQueueQueryParser = zod_1.default
    .object({
    status: zod_1.default.enum(constants_1.PAYOUT_QUEUE_STATUSES),
    canceled: parsers_2.booleanQueryParser.optional().transform((b) => (typeof b === 'undefined' ? null : b)),
})
    .and(queryParams_1.queryOffsetLimitParser);
exports.payoutQueueItemAttemptIdParser = zod_1.default
    .string()
    .startsWith(constants_1.PAYOUT_QUEUE_ITEM_ATTEMPT_ID_PREFIX)
    .transform((s) => s);
exports.payoutQueueResultParser = zod_1.default.object({
    items: zod_1.default.array(zod_1.default.object({
        status: payoutQueueItemStatusParser,
        key: parsers_common_1.payoutBatchKeyParser,
        createdAt: parsers_2.timestampParser,
        updatedAt: parsers_2.timestampParser,
        cancelled: zod_1.default.boolean().default(false),
        attempts: zod_1.default.record(exports.payoutQueueItemAttemptIdParser, zod_1.default.object({
            [constants_1.PAYOUT_QUEUE_ITEM_ATTEMPT_STARTED_AT_FIELD_NAME]: parsers_2.timestampParser,
            [constants_1.PAYOUT_QUEUE_ITEM_ATTEMPT_ENDED_AT_FIELD_NAME]: parsers_2.timestampParser.optional(),
            [constants_1.PAYOUT_QUEUE_ITEM_ATTEMPT_ERRORS_FIELD_NAME]: zod_1.default
                .record(parsers_serialized_1.payoutBatchItemCompositeKeySerializedParser, zod_1.default.string())
                .optional(),
            [constants_1.PAYOUT_QUEUE_ITEM_ATTEMPT_GLOBAL_MESSAGE_FIELD_NAME]: zod_1.default.string().optional(),
        })),
    })),
});
