"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.payoutMethodUpsertResultParser = exports.payoutMethodListResultParser = exports.payoutMethodUpsertBodyParser = exports.payoutMethodStripeTokenBodyParser = exports.payoutMethodStripeTokenResultParser = exports.payoutMethodParser = exports.payoutMethodStripeParser = exports.payoutMethodOriginTypeParser = exports.payoutMethodListQueryParser = exports.payoutMethodDeleteParamsParser = exports.payoutMethodStripeAuthorizeResultParser = exports.payoutMethodStripeAuthorizeQueryParser = void 0;
const zod_1 = require("zod");
const parsers_1 = require("../paymentMethod/parsers");
const parsers_2 = require("../stripe/parsers");
const constants_1 = require("./constants");
const constants_2 = require("../origin/constants");
const parsers_3 = require("../paypal/parsers");
exports.payoutMethodStripeAuthorizeQueryParser = zod_1.z.object({
    redirectUri: zod_1.z.string().url().optional(),
});
exports.payoutMethodStripeAuthorizeResultParser = zod_1.z.object({
    stripeConnectUrl: zod_1.z.string().url(),
});
exports.payoutMethodDeleteParamsParser = parsers_1.paymentMethodCompositeKeyParamsParser; // no offset supported (stripe works on cursors also)
exports.payoutMethodListQueryParser = parsers_1.paymentMethodListLimitParser;
exports.payoutMethodOriginTypeParser = zod_1.z.enum(constants_1.PAYOUT_METHOD_ORIGIN_TYPES);
exports.payoutMethodStripeParser = zod_1.z.object({
    originType: zod_1.z.literal(constants_2.ORIGIN_TYPE_STRIPE),
    originId: parsers_2.stripeConnectAccountIdParser,
});
exports.payoutMethodParser = zod_1.z.discriminatedUnion('originType', [
    exports.payoutMethodStripeParser,
    zod_1.z.object({
        originType: zod_1.z.literal(constants_2.ORIGIN_TYPE_PAYPAL),
        originId: parsers_3.paypalPayoutMethodIdParser,
    }),
]);
exports.payoutMethodStripeTokenResultParser = exports.payoutMethodStripeParser;
exports.payoutMethodStripeTokenBodyParser = zod_1.z.object({
    state: zod_1.z.string().transform((s) => s),
    code: zod_1.z.string(), // stripe code
});
exports.payoutMethodUpsertBodyParser = exports.payoutMethodParser;
exports.payoutMethodListResultParser = zod_1.z.array(exports.payoutMethodParser // TODO what's .end is about
    .and(zod_1.z.object({
    originType: exports.payoutMethodOriginTypeParser,
})));
exports.payoutMethodUpsertResultParser = exports.payoutMethodParser;
