import { StripeCustomerId, StripePayinMethodId } from '../stripe/types';
import { PAYIN_PROVIDER_ORIGIN_TYPES } from './constants';
import z from 'zod';
import { Subset } from '../utils/types';
import { payinProviderParamsParser, payinProviderResultParser } from './parsers';

export type PayinProviderOriginType = (typeof PAYIN_PROVIDER_ORIGIN_TYPES)[number];
export type PaypalCustomerId = 'paypal';
export type PayinProviderCustomerId = StripeCustomerId | PaypalCustomerId; // TODO + paypal email?
export type PayinProviderCustomerIdPerOriginType = {
  paypal: PaypalCustomerId;
  stripe: StripeCustomerId;
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayinProviderCustomerIdPerOriginType = Subset<
  keyof PayinProviderCustomerIdPerOriginType,
  PayinProviderOriginType
>;
export type PayinProviderPaymentMethodIdPerOriginType = {
  paypal: string;
  stripe: StripePayinMethodId;
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayinProviderPaymentMethodIdPerOriginType = Subset<
  keyof PayinProviderPaymentMethodIdPerOriginType,
  PayinProviderOriginType
>;
export type PayinProviderOriginId = PayinProviderCustomerId;

export type PayinProviderParams = z.infer<typeof payinProviderParamsParser>;
export type PayinProviderResult = z.infer<typeof payinProviderResultParser>;
