import { z } from 'zod';
import type { SessionStateString } from '../csrf/types';
import { paymentMethodCompositeKeyParamsParser, paymentMethodListLimitParser } from '../paymentMethod/parsers';
import { stripeConnectAccountIdParser } from '../stripe/parsers';
import type { Subset } from '../utils/types';
import type { PayoutMethodOriginType } from './types';
import { PAYOUT_METHOD_ORIGIN_TYPES } from './constants';
import { ORIGIN_TYPE_PAYPAL, ORIGIN_TYPE_STRIPE } from '../origin/constants';
import { paypalPayoutMethodIdParser } from '../paypal/parsers';

export const payoutMethodStripeAuthorizeQueryParser = z.object({
  redirectUri: z.string().url().optional(),
});
export const payoutMethodStripeAuthorizeResultParser = z.object({
  stripeConnectUrl: z.string().url(),
});

export const payoutMethodDeleteParamsParser = paymentMethodCompositeKeyParamsParser; // no offset supported (stripe works on cursors also)
export const payoutMethodListQueryParser = paymentMethodListLimitParser;
export const payoutMethodOriginTypeParser = z.enum(PAYOUT_METHOD_ORIGIN_TYPES);

export const payoutMethodStripeParser = z.object({
  originType: z.literal(ORIGIN_TYPE_STRIPE),
  originId: stripeConnectAccountIdParser,
});

export const payoutMethodParser = z.discriminatedUnion('originType', [
  payoutMethodStripeParser,
  z.object({
    originType: z.literal(ORIGIN_TYPE_PAYPAL),
    originId: paypalPayoutMethodIdParser,
  }),
]);

export const payoutMethodStripeTokenResultParser = payoutMethodStripeParser;
export const payoutMethodStripeTokenBodyParser = z.object({
  state: z.string().transform((s) => s as SessionStateString),
  code: z.string(), // stripe code
});

export const payoutMethodUpsertBodyParser = payoutMethodParser;

export const payoutMethodListResultParser = z.array(
  payoutMethodParser // TODO what's .end is about
    .and(
      z.object({
        originType: payoutMethodOriginTypeParser,
      })
    )
);

// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayoutMethodListResult1 = Subset<
  z.infer<typeof payoutMethodListResultParser>[number]['originType'],
  PayoutMethodOriginType
>;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayoutMethodListResult2 = Subset<
  PayoutMethodOriginType,
  z.infer<typeof payoutMethodListResultParser>[number]['originType']
>;

export const payoutMethodUpsertResultParser = payoutMethodParser;
